@@ -20,7 +20,8 @@ class RedisPool(BaseConnectionPool):
         :return:
         """
         if self.conn_info.async_enable:
-            pool = aioredis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", password=self.conn_info.password,
+            pool = aioredis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
+                                                    password=self.conn_info.password,
                                                     db=self.conn_info.db_name, encoding="utf-8", decode_responses=True)
             return pool
         else:
